# Protocol: Missing Parameters

When required parameters are missing for a task:

1. Identify which parameters are missing.
2. Ask the user for clarification using the `ask_user` tool.
3. Do not proceed until all required parameters are available.

## Example

User: "How is the weather in the US?"

Response: "Which city in the United States would you like me to check the weather for?"
